@@ -1769,7 +1769,7 @@ BWLDReadReservationQuery(
         uint32_t	*duration,
         BWLNum64	*rtt_time,
         uint16_t	*recv_port,
-        uint32_t        *tool_id,
+        BWLToolType     *tool_id,
         char            *sender,
         char            *receiver,
         int		*err
@@ -1855,6 +1855,7 @@ BWLDSendReservationResponse(
     /* real data */
     memcpy(&buf[8],&reservation,8);
     memcpy(&buf[16],&toolport,2);
+    bzero (&buf[18],2);
 
     if(I2Writeni(fd,&buf[0],24,intr) != 24){
         return 1;
@@ -1941,6 +1942,7 @@ BWLDReservationQuery(
     memcpy(&buf[48],&duration,4);
     memcpy(&buf[52],&rtt_time,8);
     memcpy(&buf[60],toolport,2);
+    bzero (&buf[62],2);
     memcpy(&buf[64],&tool,4);
     memcpy(&buf[68],sender_str,46);
     memcpy(&buf[114],receiver_str,46);
@@ -2182,6 +2184,7 @@ BWLDCheckTestPolicy(
         BWLNum64	fuzz_time,
         BWLNum64	*reservation_ret,
         uint16_t	*tool_port_ret,
+        uint16_t	*local_tool_port_ret,
         void		**closure,
         BWLErrSeverity	*err_ret
         )
@@ -2233,7 +2236,7 @@ BWLDCheckTestPolicy(
     }
 
     tinfo->node = node;
-    memcpy(tinfo->sid,sid,sizeof(sid));
+    memcpy(tinfo->sid,sid,sizeof(BWLSID));
 
     /* VALIDATE THE REQUEST! */
 
@@ -2257,7 +2260,7 @@ BWLDCheckTestPolicy(
     }
  
     lim.limit = BWLDLimDuration;
-    lim.value = tspec->duration;
+    lim.value = tspec->duration + tspec->omit;
     if(!BWLDResourceDemand(node,BWLDMESGREQUEST,lim)){
         BWLError(ctx,access_prio,BWLErrPOLICY,
                 "BWLDCheckTestPolicy: Requested test duration denied");
@@ -2270,7 +2273,7 @@ BWLDCheckTestPolicy(
 
     /* duration */
     lim.limit = BWLDLimDuration;
-    lim.value = tspec->duration;
+    lim.value = tspec->duration + tspec->omit;
     if(!BWLDResourceDemand(node,BWLDMESGREQUEST,lim)){
         BWLError(ctx,access_prio,BWLErrPOLICY,
                 "BWLDCheckTestPolicy: Requested test duration denied");
@@ -2379,7 +2382,7 @@ reservation:
      */
     if( (ret = BWLDReservationQuery(node->policy,tinfo->sid,
                     tspec->req_time.tstamp,fuzz_time,
-                    tspec->latest_time,tspec->duration,
+                    tspec->latest_time,tspec->duration + tspec->omit,
                     BWLGetRTTBound(cntrl),
                     reservation_ret,&tool_port_loc,tspec->tool_id,
                     (tspec->server_sends?tspec->server:tspec->client),
@@ -2398,6 +2401,9 @@ reservation:
     if(!local_client){
         *tool_port_ret = tool_port_loc;
     }
+
+    *local_tool_port_ret = tool_port_loc;
+
     *closure = tinfo;
     return True;
 done:
