@@ -38,7 +38,9 @@
 #ifndef    IPCNTRLP_H
 #define    IPCNTRLP_H
 
+#if defined(HAVE_STDINT_H)
 #include <stdint.h>
+#endif
 #include <stdlib.h>
 #include <stdio.h>
 #include <errno.h>
@@ -401,6 +403,7 @@ struct BWLTestSessionRec{
     BWLNum64            fuzz;
     BWLToolDefinition   tool;
     uint16_t            tool_port;
+    uint16_t            local_tool_port;
 
     BWLBoolean          conf_client;
     BWLBoolean          conf_server;
@@ -756,13 +759,12 @@ _BWLCallCloseFile(
         );
 
 /* tools.c */
-
 extern BWLBoolean
 _BWLToolInitialize(
         BWLContext  ctx
         );
 
-extern BWLBoolean
+extern BWLErrSeverity
 _BWLToolLookForTesters(
         BWLContext  ctx
         );
@@ -986,4 +988,8 @@ BWLSockaddrCompare(
         struct sockaddr *sb
         );
 
+BWLBoolean
+BWLParseCPUAffinityString(
+        const char *cpu_affinity
+        );
 #endif    /* IPCNTRLP_H */
