@@ -71,7 +71,6 @@ _BWLClientBind(
         BWLErrSeverity	*err_ret
         )
 {
-    struct addrinfo *fai;
     struct addrinfo *ai;
     BWLBoolean      retval = False;
 
@@ -279,6 +278,23 @@ TryAddr(
         goto cleanup;
     }
 
+    {
+        char            remotenode[NI_MAXHOST],remoteserv[NI_MAXSERV];
+        size_t          remotenodelen = sizeof(remotenode);
+        size_t          remoteservlen = sizeof(remoteserv);
+        char            localnode[NI_MAXHOST],localserv[NI_MAXSERV];
+        size_t          localnodelen = sizeof(localnode);
+        size_t          localservlen = sizeof(localserv);
+
+        I2AddrNodeName(cntrl->remote_addr,remotenode,&remotenodelen);
+        I2AddrServName(cntrl->remote_addr,remoteserv,&remoteservlen);
+        I2AddrNodeName(cntrl->local_addr,localnode,&localnodelen);
+        I2AddrServName(cntrl->local_addr,localserv,&localservlen);
+
+        BWLError(cntrl->ctx,BWLErrDEBUG,0, "Outbound connection to (%s:%s) from (%s:%s)",
+            remotenode,remoteserv,localnode,localserv);
+    }
+
     return 0;
 
 cleanup:
@@ -318,8 +334,6 @@ _BWLClientConnect(
     int		rc;
     struct      addrinfo	*fai;
     struct      addrinfo	*ai;
-    char        buf[NI_MAXHOST+NI_MAXSERV+3];
-    size_t      buflen = sizeof(buf);
 
     if(!server_addr)
         goto error;
@@ -559,11 +573,11 @@ BWLControlOpen(
         char buf[255];
         buf[0] = '\0';
         if (mode_avail_orig & BWL_MODE_OPEN)
-		strncat(buf, " open", sizeof(buf));
+		strncat(buf, " open", sizeof(buf) - strlen(buf) - 1);
         if (mode_avail_orig & BWL_MODE_AUTHENTICATED)
-		strncat(buf, " authenticated", sizeof(buf));
+		strncat(buf, " authenticated", sizeof(buf) - strlen(buf) - 1);
         if (mode_avail_orig & BWL_MODE_ENCRYPTED)
-		strncat(buf, " encrypted", sizeof(buf));
+		strncat(buf, " encrypted", sizeof(buf) - strlen(buf) - 1);
 
         BWLError(cntrl->ctx,BWLErrINFO,BWLErrPOLICY,
                 "Server denied access. No authentication modes in common. Modes available: %s", buf);
@@ -757,23 +771,23 @@ static int
 _BWLClientRequestTestReadResponse(
         BWLControl	cntrl,
         BWLTestSession	tsession,
-        BWLErrSeverity	*err_ret
+        BWLErrSeverity	*err_ret,
+        BWLAcceptType 	*acceptval
         )
 {
     int		rc;
-    BWLAcceptType	acceptval;
 
     if((rc = _BWLWriteTestRequest(cntrl,tsession)) < BWLErrOK){
         *err_ret = (BWLErrSeverity)rc;
         return 1;
     }
 
-    if((rc = _BWLReadTestAccept(cntrl,&acceptval,tsession)) < BWLErrOK){
+    if((rc = _BWLReadTestAccept(cntrl,acceptval,tsession)) < BWLErrOK){
         *err_ret = (BWLErrSeverity)rc;
         return 1;
     }
 
-    if(acceptval == BWL_CNTRL_ACCEPT)
+    if(*acceptval == BWL_CNTRL_ACCEPT)
         return 0;
 
     *err_ret = BWLErrOK;
@@ -805,6 +819,7 @@ BWLSessionRequest(
         BWLTimeStamp	*avail_time_ret,
         uint16_t	*tool_port,
         BWLSID		sid,
+        BWLAcceptType   *acceptval,
         BWLErrSeverity	*err_ret
         )
 {
@@ -816,13 +831,15 @@ BWLSessionRequest(
     int		    rc=0;
     I2Addr	    server=NULL;
     I2Addr	    client=NULL;
+    /*
     struct sockaddr *rsaddr;
     struct sockaddr *ssaddr;
     socklen_t       saddrlen;
+    */
     BWLNum64	    zero64=BWLULongToNum64(0);
-    BWLAcceptType   acceptval = BWL_CNTRL_FAILURE;
     BWLBoolean	    retval = False;
 
+    *acceptval = BWL_CNTRL_FAILURE;
     *err_ret = BWLErrOK;
 
     /* will be set to non-zero if request params ok */
@@ -980,10 +997,10 @@ foundaddr:
 
         /*
          * Save direct pointers to recv/send saddr's for policy funcs
-         */
         rsaddr = rai->ai_addr;
         ssaddr = sai->ai_addr;
         saddrlen = sai->ai_addrlen;
+         */
 
         /*
          * Create a structure to store the stuff we need to keep for
@@ -1006,7 +1023,7 @@ foundaddr:
      * client. (copy reservation time so a denied response can be
      * differentiated from a "busy" response.)
      */
-    rc = _BWLClientRequestTestReadResponse(cntrl,tsession,err_ret);
+    rc = _BWLClientRequestTestReadResponse(cntrl,tsession,err_ret,acceptval);
     avail_time_ret->tstamp = tsession->reserve_time;
 
     if(rc != 0){
@@ -1039,11 +1056,11 @@ cancel:
     if(_BWLWriteTestRequest(cntrl,tsession) < BWLErrOK){
         goto error;
     }
-    if(_BWLReadTestAccept(cntrl,&acceptval,tsession) < BWLErrOK){
+    if(_BWLReadTestAccept(cntrl,acceptval,tsession) < BWLErrOK){
         goto error;
     }
 
-    if(acceptval != BWL_CNTRL_REJECT){
+    if(*acceptval != BWL_CNTRL_REJECT){
         BWLError(cntrl->ctx,BWLErrFATAL,BWLErrUNKNOWN,
                 "Reservation Cancellation Error");
         _BWLFailControlSession(cntrl,BWLErrFATAL);
@@ -1051,7 +1068,7 @@ cancel:
 
 error:
     if(tsession){
-        _BWLTestSessionFree(cntrl->ctx, tsession,acceptval);
+        _BWLTestSessionFree(cntrl->ctx, tsession,*acceptval);
         if(cntrl->tests == tsession){
             cntrl->tests = NULL;
         }
