@@ -55,6 +55,9 @@
  */
 #include <bwlib/bwlibP.h>
 #include <assert.h>
+#include <signal.h>
+
+static BWLBoolean _TasksetAvailable(BWLContext ctx);
 
 static BWLToolDefinitionRec BWLToolNone = {
     "",
@@ -68,12 +71,15 @@ static BWLToolDefinitionRec BWLToolNone = {
     NULL
 };
 
+static taskset_available = True;
+
 /* autoconf seletion of tools here... */
 
 extern BWLToolDefinitionRec BWLToolOwamp;
 extern BWLToolDefinitionRec BWLToolPing;
 extern BWLToolDefinitionRec BWLToolTraceroute;
 extern BWLToolDefinitionRec BWLToolTracepath;
+extern BWLToolDefinitionRec BWLToolParisTraceroute;
 
 #ifdef  TOOL_IPERF
 extern BWLToolDefinitionRec BWLToolIperf;
@@ -81,11 +87,7 @@ extern BWLToolDefinitionRec BWLToolIperf;
 #define BWLToolIperf    BWLToolNone
 #endif
 
-#ifdef  TOOL_IPERF3
 extern BWLToolDefinitionRec BWLToolIperf3;
-#else
-#define BWLToolIperf3    BWLToolNone
-#endif
 
 #ifdef  TOOL_NUTTCP
 extern BWLToolDefinitionRec BWLToolNuttcp;
@@ -103,6 +105,7 @@ BWLToolRec tool_list[] = {
     {BWL_TOOL_OWAMP,  &BWLToolOwamp},
     {BWL_TOOL_TRACEPATH, &BWLToolTracepath},
     {BWL_TOOL_TRACEROUTE, &BWLToolTraceroute},
+    {BWL_TOOL_PARIS_TRACEROUTE, &BWLToolParisTraceroute},
     {BWL_TOOL_PING,  &BWLToolPing},
     {BWL_TOOL_IPERF, &BWLToolIperf},
     {BWL_TOOL_IPERF3, &BWLToolIperf3},
@@ -210,7 +213,7 @@ BWLToolGetTestTypesByID(
         }
     }
 
-    return BWL_DATA_UNKNOWN;
+    return BWL_TEST_UNDEFINED;
 }
 
 
@@ -481,8 +484,11 @@ _BWLToolLookForTesters(
         return BWLErrFATAL;
     }
 
+    taskset_available = _TasksetAvailable(ctx);
+
     BWLError(ctx,BWLErrDEBUG,BWLErrUNKNOWN,
             "Available tools: %s", BWLToolGetToolNames(ctx,ctx->tool_avail));
+
     return BWLErrOK;
 }
 
@@ -605,7 +611,7 @@ save_path(
     }
 
     strcpy(optname,"V.");
-    strncat(optname,key,sizeof(optname));
+    strncat(optname,key,sizeof(optname) - strlen(optname) - 1);
     if(BWLContextConfigSet(ctx,optname,str)){
         return 1;
     }
@@ -635,7 +641,7 @@ save_ports(
     *ports = *portrangerec;
 
     strcpy(optname,"V.");
-    strncat(optname,key,sizeof(optname));
+    strncat(optname,key,sizeof(optname) - strlen(optname) - 1);
     if(BWLContextConfigSet(ctx,optname,ports)){
         return 1;
     }
@@ -696,6 +702,30 @@ _BWLToolGenericParse(
         return 1;
     }
 
+    snprintf(confkey, sizeof(confkey) - 1, "%s_cpu_affinity", tool->name);
+    if(!strncasecmp(key,confkey,strlen(confkey))){
+        if (!BWLParseCPUAffinityString(val)) {
+            BWLError(ctx,BWLErrFATAL,errno,
+                    "BWLToolGenericParse: %s: \'%s\' - invalid cpu affinity string",
+                    confkey,val);
+            return -1;
+        }
+
+        return save_path(ctx,key,val);
+    }
+
+    snprintf(confkey, sizeof(confkey) - 1, "test_cpu_affinity");
+    if(!strncasecmp(key,confkey,strlen(confkey))){
+        if (!BWLParseCPUAffinityString(val)) {
+            BWLError(ctx,BWLErrFATAL,errno,
+                    "BWLToolGenericParse: %s: \'%s\' - invalid cpu affinity string",
+                    confkey,val);
+            return -1;
+        }
+
+        return save_path(ctx,key,val);
+    }
+
     snprintf(confkey, sizeof(confkey) - 1, "test_port");
     if(!strncasecmp(key,confkey,strlen(confkey))){
         BWLPortRangeRec portrange;
@@ -748,8 +778,7 @@ _BWLToolGenericInitTest(
 
     // Check if a default "test_port" range is set
     if( !prange ) {
-        strncpy(optname, "V.test_port", sizeof(optname));
-        prange = (BWLPortRange)BWLContextConfigGetV(ctx,optname);
+        prange = (BWLPortRange)BWLContextConfigGetV(ctx,"V.test_port");
     }
 
     // If nothing has been specified for this tool, initialize it to a range of
@@ -758,14 +787,14 @@ _BWLToolGenericInitTest(
     if( !prange ) {
         prange = calloc(1,sizeof(BWLPortRangeRec));
         if(prange) {
-            prange->low  = tool->def_port - 1;
-            prange->high = tool->def_port + 100;
-            BWLPortsSetI(ctx,prange,tool->def_port);
-            BWLContextConfigSet(ctx,optname,prange);
+            prange->low  = 5001;
+            prange->high = 5900;
+            BWLPortsSetI(ctx,prange,5001);
+            BWLContextConfigSet(ctx,"V.test_port",prange);
         }
     }
 
-    if( (prange = (BWLPortRange)BWLContextConfigGetV(ctx,optname))){
+    if( prange ) {
         *toolport = BWLPortsNext(prange);
     }
     else{
@@ -931,3 +960,67 @@ _BWLToolGenericKillTest(
         return False;
     }
 }
+
+static BWLBoolean
+_TasksetAvailable(
+        BWLContext          ctx
+        )
+{
+    int             len;
+    char            *cmd;
+    char            buf[1024];
+    int             n;
+
+    /*
+     * Fetch 'tool' name
+     */
+    if( !(cmd = (char *)BWLContextConfigGetV(ctx,"V.taskset_cmd"))){
+        cmd = "taskset";
+    }
+
+    n = ExecCommand(ctx, buf, sizeof(buf), cmd, "-h", NULL);
+    if(n == 0) {
+        return True;
+   }
+
+   BWLError(ctx,BWLErrWARNING,BWLErrUNKNOWN,
+        "_TasksetAvailable(): Unable to find 'taskset' command. Setting the CPU affinity will not be supported");
+
+   return False;
+}
+
+int
+BWLToolGenericFillCPUAffinityCommand(
+        BWLContext          ctx,
+        BWLToolDefinition   tool,
+        char **cmdline
+        )
+{
+    char confkey[1024];
+    char *cmd, *cpu_affinity;
+    int i;
+
+    if (!taskset_available)
+        return 0;
+
+    snprintf(confkey, sizeof(confkey) - 1, "V.%s_cpu_affinity", tool->name);
+    cpu_affinity = (char*)BWLContextConfigGetV(ctx,confkey);
+    if (!cpu_affinity) {
+        cpu_affinity = (char*)BWLContextConfigGetV(ctx,"V.test_cpu_affinity");
+    }
+
+    if (!cpu_affinity)
+        return 0;
+
+    if( !(cmd = (char *)BWLContextConfigGetV(ctx,"V.taskset_cmd"))){
+        cmd = "taskset";
+    }
+
+    i = 0;
+
+    cmdline[i++] = cmd;
+    cmdline[i++] = "-c";
+    cmdline[i++] = cpu_affinity;
+
+    return i;
+}
